"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePriceInSol = void 0;
const useSolPrice_1 = require("./useSolPrice");
const bondingPricing_1 = require("./bondingPricing");
const spl_token_1 = require("@solana/spl-token");
const react_1 = require("react");
const useTwWrappedSolMint_1 = require("./useTwWrappedSolMint");
const useMetaplexMetadata_1 = require("./useMetaplexMetadata");
const useCoinGeckoPrice_1 = require("./useCoinGeckoPrice");
function usePriceInSol(token) {
    const solPrice = (0, useSolPrice_1.useSolPrice)();
    const { pricing, tokenBonding, loading: pricingLoading } = (0, bondingPricing_1.useBondingPricingFromMint)(token);
    const lowestMint = (0, react_1.useMemo)(() => {
        const arr = (pricing === null || pricing === void 0 ? void 0 : pricing.hierarchy.toArray()) || [];
        if (arr.length > 0) {
            return arr[arr.length - 1].tokenBonding.baseMint;
        }
    }, [pricing]);
    const { metadata, loading } = (0, useMetaplexMetadata_1.useMetaplexTokenMetadata)(lowestMint);
    const { metadata: inputMeta } = (0, useMetaplexMetadata_1.useMetaplexTokenMetadata)(token);
    const [price, setPrice] = (0, react_1.useState)();
    const wrappedSolMint = (0, useTwWrappedSolMint_1.useTwWrappedSolMint)();
    (0, react_1.useEffect)(() => {
        var _a;
        if ((token === null || token === void 0 ? void 0 : token.equals(spl_token_1.NATIVE_MINT)) ||
            (wrappedSolMint && (token === null || token === void 0 ? void 0 : token.equals(wrappedSolMint)))) {
            setPrice(1);
        }
        else if (pricing) {
            if (wrappedSolMint) {
                const currentPricing = pricing === null || pricing === void 0 ? void 0 : pricing.current(lowestMint);
                if (wrappedSolMint && (lowestMint === null || lowestMint === void 0 ? void 0 : lowestMint.equals(wrappedSolMint))) {
                    setPrice(currentPricing);
                }
                else if (wrappedSolMint && !loading && solPrice) {
                    (_a = (0, useCoinGeckoPrice_1.getCoinGeckoPriceUsd)(metadata === null || metadata === void 0 ? void 0 : metadata.data.name)) === null || _a === void 0 ? void 0 : _a.then((p) => {
                        if (p) {
                            const newPrice = (p * currentPricing) / solPrice;
                            setPrice(newPrice);
                        }
                    }).catch(console.error);
                }
            }
        }
    }, [token, solPrice, pricing, tokenBonding, loading, wrappedSolMint]);
    (0, react_1.useEffect)(() => {
        var _a;
        if (!pricing && !pricingLoading && inputMeta && solPrice) {
            (_a = (0, useCoinGeckoPrice_1.getCoinGeckoPriceUsd)(inputMeta === null || inputMeta === void 0 ? void 0 : inputMeta.data.name)) === null || _a === void 0 ? void 0 : _a.then((p) => {
                if (p) {
                    const newPrice = p / solPrice;
                    setPrice(newPrice);
                }
            }).catch(console.error);
        }
    }, [inputMeta, pricingLoading, pricing, solPrice]);
    return price;
}
exports.usePriceInSol = usePriceInSol;
//# sourceMappingURL=usePriceInSol.js.map